chop.stochastic
===============

.. automodule:: chop.stochastic

   
   
   

   
   
   .. rubric:: Functions

   .. autosummary::
   
      backtracking_step_size
      normalize_gradient
   
   

   
   
   .. rubric:: Classes

   .. autosummary::
   
      FrankWolfe
      PGD
      PGDMadry
      PairwiseFrankWolfe
      S3CM
   
   

   
   
   



